import numpy as np
import matplotlib.pyplot as plt

from uncertainties import ufloat as uf
from uncertainties import unumpy as unp

ff1, mag1, pha1 = np.loadtxt('IssDarmTf01.txt', unpack=1)
ff2, mag2, pha2 = np.loadtxt('IssDarmTf02.txt', unpack=1)
_, coh1 = np.loadtxt('IssDarmCoh01.txt', unpack=1)
_, coh2 = np.loadtxt('IssDarmCoh02.txt', unpack=1)
ff = np.concatenate([ff1[ff1<ff2[0]], ff2, ff1[ff1>ff2[-1]]])
mag = np.concatenate([mag1[ff1<ff2[0]], mag2, mag1[ff1>ff2[-1]]])
pha = np.concatenate([pha1[ff1<ff2[0]], pha2, pha1[ff1>ff2[-1]]])
coh = np.concatenate([coh1[ff1<ff2[0]], coh2, coh1[ff1>ff2[-1]]])
ff = ff[coh>0.9]
mag = mag[coh>0.9]
pha = pha[coh>0.9]
coh = coh[coh>0.9]
navg = 10/1.89
frunc = np.sqrt((1-coh)/(coh*2*navg))

mag = unp.uarray(mag, mag*frunc) / 5.4e-7 * 1e6
pha = unp.uarray(pha, frunc)

h = plt.figure(figsize=(8, 8))
plt.subplot(211)
plt.errorbar(ff, unp.nominal_values(mag), unp.std_devs(mag), fmt='.')
plt.yscale('symlog', linthreshy=1e-9)
plt.xscale('log')
plt.ylim(7, 1.1e3)
plt.ylabel('Magnitude [mA/W]')
plt.title(r'IM4 trans sum $\rightarrow$ OMC DC sum')
plt.subplot(212)
plt.errorbar(ff, unp.nominal_values(pha), unp.std_devs(pha), fmt='.')
plt.semilogx()
plt.ylabel('Phase [deg.]')
plt.tight_layout()
plt.savefig('tf01.pdf')

plt.figure(figsize=(8, 6))
f3, darm = np.loadtxt('Darm_20150324_050820.txt', unpack=1)
f2, im4 = np.loadtxt('IM4Trans.txt', unpack=1)
im4 *= 1e-6
mag2 = np.interp(f2, ff, unp.nominal_values(mag))
im4 = im4[f2>40]
mag2 = mag2[f2>40]
f2 = f2[f2>40]
plt.loglog(f2, im4*mag2*4.6e-13*np.abs(1+1j*f2/389))
plt.loglog(f3, darm)
plt.xlim(2, 7e3)
plt.ylim(9e-22, 1e-11)
plt.xlabel('Frequency [Hz]')
plt.ylabel('ASD of displacement [m Hz$^{-1/2}$]')
plt.title('H1 DARM, 2015-03-24 05:08:20 UTC')
plt.tight_layout()
plt.savefig('im4darm.pdf')
